@@ -19,63 +19,7 @@ from decimal import Decimal
 from datetime import datetime as dt
 import time
 
-
-def data_conv(data):
-    if data == '':
-        data = None
-    else:
-        data = float(data)
-    return data
-
-
-def data_conv_int(data):
-    if data == '':
-        data = None
-    else:
-        data = int(data)*1000
-    return data
-
-def return_img_stream(img_local_path):
-    img_stream = ''
-    with open(img_local_path, 'rb') as img_f:
-        img_stream = img_f.read()
-        img_stream = base64.b64encode(img_stream).decode()
-    return img_stream
-
-# if request.method == "POST":
-# note = []
-# # Generation of Ocean Wave Point Spectra
-# # Inputs
-# # Primary
-# c1 = int(request.form["c1"])
-# if c1 == 1:
-#     d = float(request.form["d"])   # water depth (m)    
-#     X = request.form["X"]
-#     X = data_service.data_conv_int(X)            
-#     U = float(request.form["U"])  # wind speed (m/s)
-#     el = float(request.form["el"])   # the elevation of the wind speed (m)      
-#     gamma = float(request.form["gamma"])   # peakedness parameter for JONSWAP (between 1 and 7, but 3.30 is normally recommended)
-#     Hs = float(request.form["Hs"])   # significant wave height (m)
-#     Tz = float(request.form["Tz"])  # average zero-crossing period from data (s)
-#     Ts = request.form["Ts"] # significant wave period (s)
-#     Ts = data_service.data_conv(Ts)
-#     Tp = None
-
-# # If c1=2, please input the following paramaters:
-# if c1 == 2:
-#     X = request.form["X"]
-#     X = data_service.data_conv_int(X)   # fetch length (m)
-#     U = float(request.form["U"])   # wind speed m/s).             
-#     el = request.form["el"]  # the elevation of the wind speed (m). 
-#     el = data_service.data_conv(el)            
-#     gamma = float(request.form["gamma"])   # peakedness parameter in JONSWAP (between 1 and 7, but 3.30 is normally recommended). Optional
-#     Hs = float(request.form["Hs"])   # 5 # significant wave height (m)  
-#     Tz = request.form["Tz"]  # measured average zero-crossing period (s)
-#     Tz = data_service.data_conv(Tz)
-#     Ts = float(request.form["Ts"])   # measured significant period (s)
-#     Tp = request.form["Tp"]  # Tz: period of spectral peak (s)
-#     Tp = data_service.data_conv(Tp)
-#     d = None       
+from .ref_func import data_conv, data_conv_int, return_img_stream
 
 def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     note = []
@@ -721,13 +665,5 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     img.seek(0)
     img_stream = base64.b64encode(img.getvalue()).decode()
     plt.close("all")
-    # print(note)
-    # print(img_stream)
-    # print(data1_heading)
-    # print(data2_heading)
-    # print(data1)
-    # print(data2)
-    # print(content)
-    # return  img_stream, heading, data1, data1_heading1, data1_heading2, data2, data2_heading1, data2_heading2, content, ending
     return  img_stream, heading, data1, data1_heading, data2, data2_heading, content, ending
     # return  img_stream, note
